import type { RouteRecordRaw } from 'vue-router'
import MainLayout from '@/layout/main/index.vue'
/** 评阅试卷 */
const markingRoutes: RouteRecordRaw[] = [
  {
    name: 'Marking',
    path: '/marking',
    component: MainLayout,
    meta: {
      menu: true,
      menuId: 'marking',
      label: '评阅试卷',
      icon: 'nav-expert',
      sort: 3,
    },
    children: [
      {
        name: 'MarkingNav',
        path: '',
        component: () => import('@/modules/marking/nav/index.vue'),
      },
      {
        name: 'MarkingAssess',
        path: 'assess',
        component: () => import('@/modules/marking/assess/index.vue'),
        meta: {
          label: '强制考核分发',
          menu: true,
          menuId: 'marking-assess',
          sort: 5,
        },
      },
      {
        name: 'MarkingInquiry',
        path: 'inquiry',
        component: () => import('@/modules/marking/inquiry/index.vue'),
        meta: {
          label: '自定义查询',
          menu: true,
          menuId: 'marking-inquiry',
          sort: 6,
        },
      },
      {
        name: 'MarkingStatistics',
        path: 'statistics',
        component: () => import('@/modules/marking/statistics/index.vue'),
        meta: {
          label: '个人统计',
          menu: true,
          menuId: 'marking-statistics',
          sort: -7,
        },
      },
    ],
  },
  {
    name: 'MarkingArbitration',
    path: '/marking/arbitration',
    component: () => import('@/modules/marking/arbitration/index.vue'),
    meta: {
      label: '仲裁卷',
      menu: true,
      menuId: 'marking-arbitration',
      sort: 1,
    },
  },
  {
    name: 'MarkingProblem',
    path: '/marking/problem',
    component: () => import('@/modules/marking/problem/index.vue'),
    meta: {
      label: '问题卷',
      menu: true,
      menuId: 'marking-problem',
      sort: 2,
    },
  },
  {
    name: 'MarkingSimilar',
    path: '/marking/similar',
    component: () => import('@/modules/marking/similar/index.vue'),
    meta: {
      label: '雷同卷',
      menu: true,
      menuId: 'marking-similar',
      sort: 3,
    },
  },
  {
    name: 'MarkingRepeat',
    path: '/marking/repeat',
    component: () => import('@/modules/marking/repeat/index.vue'),
    meta: {
      label: '重评卷',
      menu: true,
      menuId: 'marking-repeat',
      sort: 4,
    },
  },
  {
    name: 'MarkingMark',
    path: '/marking/mark',
    component: () => import('@/modules/marking/mark/index.vue'),
    meta: {
      label: '正常评卷',
      menu: true,
      menuId: 'marking-mark',
      sort: -9,
    },
  },
  {
    name: 'MarkingTrainingRecord',
    path: '/marking/training-record',
    component: () => import('@/modules/marking/training-record/index.vue'),
    meta: {
      label: '查看培训记录',
      menu: true,
      menuId: 'marking-training_record',
      sort: -8,
    },
  },
  {
    name: 'SubmitSimilar',
    path: '/marking/submit-similar/:taskId',
    props: true,
    component: () => import('@/modules/marking/submit-similar/index.vue'),
    meta: {
      label: '提交雷同卷',
      menu: false,
      menuId: 'marking-submit_similar',
      sort: -7,
    },
  },
  {
    name: 'MarkingStandard',
    path: '/marking-standard',
    component: MainLayout,
    meta: {
      label: '评卷标准浏览',
      menu: true,
      menuId: 'marking_standard',
      icon: 'nav-standard',
      sort: 4,
    },
    children: [
      {
        path: '',
        name: 'MarkingStandardNav',
        component: () => import('@/modules/marking/standard-nav/index.vue'),
      },
      {
        name: 'MarkStandard',
        path: 'mark',
        component: () => import('@/modules/marking/marking-standard/index.vue'),
        meta: {
          label: '评分标准',
          menu: true,
          menuId: 'marking_standard-score_standard',
          sort: 2,
        },
      },
    ],
  },
  {
    name: 'MarkingViewSample',
    path: '/marking/view-sample',
    component: () => import('@/modules/marking/view-sample/index.vue'),
    meta: {
      label: '查看样卷',
      menu: true,
      menuId: 'marking_standard-view_sample',
      sort: 1,
    },
  },
  {
    name: 'SystemCheck',
    path: '/system-check',
    component: () => import('@/modules/monitor/system-check/index.vue'),
    meta: {
      label: '系统抽查卷',
      menu: true,
      menuId: 'marking-system_check',
    },
  },
  {
    name: 'MarkingInquiryResult',
    path: '/inquiry-result',
    component: () => import('@/modules/marking/inquiry-result/index.vue'),
    meta: {
      label: '自定义查询结果页',
      menu: false,
      menuId: 'marking-inquiry_result',
    },
  },
]

export default markingRoutes
